<?php

namespace Drupal\protected_download;

use Drupal\protected_download\PolicyInterface;

/**
 * Protected download policy for responses cacheable within a given period.
 *
 * Computes an expiry date which is aligned according to fixed time frames.
 */
class AlignedTtlPolicy implements PolicyInterface {

  /**
   * Default minimum ttl for protected download links with aligned expiry date.
   *
   * Defaults to one day.
   */
  const DEFAULT_ALIGNED_MIN_TTL = 86400;

  /**
   * Default maximum ttl for protected download links with aligned expiry date.
   *
   * Defaults to 7 plus 1 days.
   */
  const DEFAULT_ALIGNED_MAX_TTL = self::DEFAULT_ALIGNED_MIN_TTL + 604800;

  /**
   * Minimum number of seconds the generated link should be valid.
   */
  protected $minTtl;

  /**
   * Maximum number of seconds the generated link should be valid.
   */
  protected $maxTtl;

  /**
   * Constructs a new aligned TTL policy.
   *
   * @param int $min_ttl
   *   Minimum number of seconds the generated link should be valid.
   * @param int $max_ttl
   *   Maximum number of seconds the generated link should be valid.
   */
  public function __construct(int $min_ttl, int $max_ttl) {
    $this->minTtl = $min_ttl;
    $this->maxTtl = $max_ttl;
  }

  /**
   * {@inheritdoc}
   */
  public function isPrivate(): bool {
     return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function expire(int $time): int {
    $deltaTtl = $this->maxTtl - $this->minTtl;
    return (int) ($this->minTtl + $deltaTtl * ceil($time / $deltaTtl));
    }
}
